@@ -46,8 +46,12 @@ Check if given terminal `tty` supports sixel format.
     (Experiment) The return value is not fully tested on all terminals and all platforms.
 """
 function is_sixel_supported(tty::Base.TTY=stdout)
-    device_attributes = TerminalTools.query_terminal("\033[0c", tty)
-    "4" in split(chop(device_attributes), ';')
+    try
+        device_attributes = TerminalTools.query_terminal("\033[0c", tty)
+        "4" in split(chop(device_attributes), ';')
+    catch
+        return false
+    end
 end
 is_sixel_supported(io::IO) = false
 
